@@ -8,8 +8,7 @@ from trytond.transaction import Transaction
 __all__ = ['Statement', 'StatementLine']
 
 
-class Statement:
-    __metaclass__ = PoolMeta
+class Statement(metaclass=PoolMeta):
     __name__ = 'account.statement'
 
     @classmethod
@@ -63,8 +62,7 @@ class Statement:
         return key + (('payment', line.payment),)
 
 
-class StatementLine:
-    __metaclass__ = PoolMeta
+class StatementLine(metaclass=PoolMeta):
     __name__ = 'account.statement.line'
     payment = fields.Many2One('account.payment', 'Payment',
         domain=[
@@ -103,7 +101,7 @@ class StatementLine:
         else:
             default = default.copy()
         default.setdefault('payment', None)
-        default.setdefault('payment_group')
+        default.setdefault('payment_group', None)
         return super(StatementLine, cls).copy(lines, default=default)
 
     @fields.depends('payment', 'party', 'account', '_parent_statement.journal')
@@ -158,4 +156,6 @@ class StatementLine:
         Move = pool.get('account.move')
         super(StatementLine, cls).post_move(lines)
         Move.post([l.payment.clearing_move for l in lines
-                if l.payment and l.payment.clearing_move])
+                if l.payment
+                and l.payment.clearing_move
+                and l.payment.clearing_move.state == 'draft'])
